{ pkgs, ... }:
{
  programs.jujutsu = {
    enable = true;
    settings = {
      user = {
        name = "jolheiser";
        email = "git@jolheiser.com";
      };
      ui = {
        diff.tool = [
          "${pkgs.difftastic}/bin/difft"
          "--color=always"
          "$left"
          "$right"
        ];
        editor = "hx";
        paginate = "never";
        default-command = "log";
      };
      git.push-bookmark-prefix = "change/";
      signing = {
        behavior = "own";
        backend = "ssh";
        key = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIAUxLwkJOlalAHTdkbh+m49XTZGKDqWz1o/o8OLmtQdX";
      };
      revsets.log = "ancestors(present(@), 5) | ancestors(immutable_heads().., 2) | present(trunk())";
      revset-aliases = {
        "closest_bookmark(to)" = "heads(::to & bookmarks())";
        "immutable_heads()" = "builtin_immutable_heads() & remote_bookmarks()";
      };
      aliases = {
        push = [
          "util"
          "exec"
          "git"
          "push"
          "origin"
          "main"
        ];
        fetch = [
          "util"
          "exec"
          "git"
          "fetch"
          "origin"
        ];
        i = [
          "git"
          "init"
          "--colocate"
        ];
        tug = [
          "bookmark"
          "move"
          "--from"
          "closest_bookmark(@-)"
          "--to"
          "@-"
        ];
      };
    };
  };
}
