{
  description = "jolheiser's nixos config";

  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixos-unstable";
    home-manager = {
      url = "github:nix-community/home-manager";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    agenix = {
      url = "github:ryantm/agenix";
      inputs = {
        darwin.follows = "";
        home-manager.follows = "home-manager";
        nixpkgs.follows = "nixpkgs";
      };
    };
    nixos-hardware.url = "github:nixos/nixos-hardware/master";
    nur.url = "github:nix-community/NUR";
    helix.url = "git+https://git.jolheiser.com/helix.drv.git";
    gomodinit.url = "git+https://git.jolheiser.com/gomodinit.git";
    cfg.url = "git+https://git.jolheiser.com/cfg.git";
    spectre.url = "git+https://git.jolheiser.com/go-spectre.git";
    pokego.url = "git+https://git.jolheiser.com/pokego.git";
    tclip.url = "github:tailscale-dev/tclip";
  };

  outputs =
    {
      nixpkgs,
      home-manager,
      nixos-hardware,
      agenix,
      ...
    }@inputs:
    let
      overlay = _: prev: {
        nur = import inputs.nur {
          nurpkgs = prev;
          pkgs = prev;
        };
        jolheiser = {
          helix = inputs.helix.packages.${prev.system}.default;
          gomodinit = inputs.gomodinit.packages.${prev.system}.default;
          cfg = inputs.cfg.packages.${prev.system}.default;
          spectre = inputs.spectre.packages.${prev.system}.default;
          pokego = inputs.pokego.packages.${prev.system}.default;
        };
        tclip = inputs.tclip.packages.${prev.system}.tclip;
      };
      pkgs = import inputs.nixpkgs {
        inherit system;
        overlays = [ overlay ];
        config.allowUnfree = true;
      };
      commonConfig =
        { config, ... }:
        {
          config = {
            nixpkgs.overlays = [ overlay ];
          };
        };
      username = "jolheiser";
      system = "x86_64-linux";
      homeManagerModules = [
        agenix.homeManagerModules.age
        {
          home = {
            inherit username;
            homeDirectory = "/home/${username}";
          };
          age = {
            secretsDir = "/home/${username}/.agenix/agenix";
            secretsMountPoint = "/home/${username}/.agenix/agenix.d";
            identityPaths = [ "/home/${username}/.ssh/nix" ];
            secrets = {
              ssh-config.file = ./secrets/ssh-config.age;
              spotify = {
                file = ./secrets/spotify.age;
                path = "/home/${username}/.cache/spotify-player/credentials.json";
              };
              irc-pw.file = ./secrets/irc-pw.age;
              spectre-pw.file = ./secrets/spectre-pw.age;
              git-send-email.file = ./secrets/git-send-email.age;
              cachix = {
                file = ./secrets/cachix.age;
                path = "/home/${username}/.config/cachix/cachix.dhall";
              };
              llm = {
                file = ./secrets/llm.age;
                path = "/home/${username}/.config/io.datasette.llm/keys.json";
              };
            };
          };
        }
        ./apps/gui
      ];
    in
    {
      inherit homeManagerModules;
      overlays.jolheiser = overlay;
      overlays.default = overlay;
      homeConfigurations = {
        "jolheiser" = home-manager.lib.homeManagerConfiguration {
          inherit pkgs;
          modules = homeManagerModules ++ [ ./apps/de ];
        };
      };
      nixosConfigurations = {
        "genmaicha" = nixpkgs.lib.nixosSystem {
          inherit system;
          modules = [
            nixos-hardware.nixosModules.framework-13-7040-amd
            ./machines/genmaicha
            commonConfig
          ];
        };
        "sencha" = nixpkgs.lib.nixosSystem {
          inherit system;
          modules = [
            ./machines/sencha
            commonConfig
          ];
        };
      };
      devShells.${system}.default = pkgs.mkShell {
        nativeBuildInputs = [
          agenix.packages.${system}.agenix
        ];
      };
    };
}
